@@ -1,32 +1,30 @@
 package Test::Magpie::Inspect;
 {
-  $Test::Magpie::Inspect::VERSION = '0.08';
+  $Test::Magpie::Inspect::VERSION = '0.09';
 }
-# ABSTRACT: Inspect invocations of methods on mocks
+# ABSTRACT: Inspect method invocations on mock objects
+
 use Moose;
 use namespace::autoclean;
 
 use aliased 'Test::Magpie::Invocation';
 
-use MooseX::Types::Moose qw( Int Str );
-use MooseX::Types::Structured qw( Map );
-
-use List::AllUtils qw( first );
+use List::Util qw( first );
 use Test::Magpie::Util qw( extract_method_name get_attribute_value );
 
 with 'Test::Magpie::Role::HasMock';
 
 our $AUTOLOAD;
+
 sub AUTOLOAD {
     my $self = shift;
-    my $method_name = extract_method_name($AUTOLOAD);
 
     my $inspect = Invocation->new(
-        method_name => $method_name,
+        method_name => extract_method_name($AUTOLOAD),
         arguments   => \@_,
     );
 
-    my $mock = get_attribute_value($self, 'mock');
+    my $mock        = get_attribute_value($self, 'mock');
     my $invocations = get_attribute_value($mock, 'invocations');
 
     return first { $inspect->satisfied_by($_) } @$invocations;
@@ -43,7 +41,7 @@ __END__
 
 =head1 NAME
 
-Test::Magpie::Inspect - Inspect invocations of methods on mocks
+Test::Magpie::Inspect - Inspect method invocations on mock objects
 
 =head1 SYNOPSIS
 
@@ -56,13 +54,14 @@ Test::Magpie::Inspect - Inspect invocations of methods on mocks
 
 =head1 DESCRIPTION
 
-Inspecting a mock objects allows you to write slightly clearer tests than having
-a complex verification call. L<Test::Magpie/inspect> gives back an object of
-this class that, like other functions, has the same API as your mock object.
+Inspecting a mock object allows you to write slightly clearer tests than having
+a complex verification call.
 
-When a method is called, we see if any invocation matches it's name and argument
-specification (inspectors can use argument matchers), and if so - return that
-invocation as a L<Test::Magpie::Invocation>. Otherwise, C<undef> is returned.
+L<Test::Magpie/inspect> gives back an object of this class that has the same
+API as your mock object. When a method is called, it checks if any invocation
+matches its name and argument specification (inspectors can use argument
+matchers). If so it will return that invocation as a L<Test::Magpie::Invocation>
+object. Otherwise, C<undef> is returned.
 
 =head1 AUTHORS
 
