@@ -1,8 +1,9 @@
 package Test::Magpie::When;
 {
-  $Test::Magpie::When::VERSION = '0.08';
+  $Test::Magpie::When::VERSION = '0.09';
 }
 # ABSTRACT: The process of stubbing a mock method call
+
 use Moose;
 use namespace::autoclean;
 
@@ -12,13 +13,14 @@ use Test::Magpie::Util qw( extract_method_name get_attribute_value );
 with 'Test::Magpie::Role::HasMock';
 
 our $AUTOLOAD;
+
 sub AUTOLOAD {
     my $self = shift;
     my $method_name = extract_method_name($AUTOLOAD);
 
     my $stub = Stub->new(
         method_name => $method_name,
-        arguments => \@_
+        arguments   => \@_,
     );
 
     my $mock  = get_attribute_value($self, 'mock');
